@@ -112,7 +112,7 @@ static void fix_one_key(char* argp, MYSQL_RES* res, MYSQL_ROW row)
     /*
      * Feed the url_md5 key
      */
-    sprintf(query, "update %s set url_md5 = '%s' where rowid = %s", arg->table, str2md5ascii_simple(cannonical_url, strlen(cannonical_url)), rowid);
+    sprintf(query, "update %s set url_md5 = '%.*s' where rowid = %s", arg->table, MD5_ASCII_SIZE, str2md5ascii_simple(cannonical_url, strlen(cannonical_url)), rowid);
     {
       int ret;
       if((ret = mysql_query(&base->mysql, query))) {
@@ -327,6 +327,7 @@ static void init(int argc, char** argv)
   {
     /* These options set a flag. */
     {"verbose", 0, &verbose, 1},
+    {"help", 0, 0, 0},
     {"fake", 0, &params.fake, 1},
     {"keys", 0, &params.keys, 1},
     {"keys_md5", 0, &params.keys_md5, 1},
@@ -338,7 +339,27 @@ static void init(int argc, char** argv)
     {0, MAX_OPTIONS, 0, APPLICATION_OPTIONS}
   };
 
+  char buf[8];
+  snprintf(buf,8,"%d",MAX_OPTIONS);
+
+  static struct option_help long_options_help[MAX_OPTIONS + 1] =
+  {
+    /* These options set a flag. */
+    {"verbose", ""},
+    {"fake", ""},
+    {"help", "displays this message"},
+    {"keys", ""},
+    {"keys_md5", ""},
+    {"keys_normalize", ""},
+    {"keys_url", ""},
+    {"log", ""},
+    {"repair", ""},
+    {"verbose_sqlutil", ""},
+    {"0", buf}
+  };
+
   getopt_merge(long_options, webbase_options(long_options));
+  getopt_help_merge(long_options_help, webbase_help_options(long_options_help));
 
   opterr = 0;
   optind = 0;
@@ -363,6 +384,9 @@ static void init(int argc, char** argv)
 	  params.log = strdup(optarg);
 	} else if(!strcmp(long_options[option_index].name, "verbose_sqlutil")) {
 	  sqlutil_verbose(1);
+	} else if(!strcmp(long_options[option_index].name, "help")) {
+	  getopt_dump(long_options_help);
+	  exit(0);
 	} else if(!strcmp(long_options[option_index].name, "")) {
 	}
 	break;
@@ -373,7 +397,7 @@ static void init(int argc, char** argv)
 
   if(params.log) logfile(params.log);
 
-  if(verbose > 1) getopt_dump(long_options);
+  if(verbose > 1) getopt_dump(long_options_help);
 
   return;
 }
