@@ -36,6 +36,7 @@
 #ifdef HAVE_DMALLOC_H
 #include <dmalloc.h>
 #endif /* HAVE_DMALLOC_H */
+#include <sys/stat.h>
 
 #include <hash.h>
 #include <getopttools.h>
@@ -48,9 +49,11 @@
 #include <rm.h>
 #include <creatp.h>
 #include <base64.h>
+#include <strsubs.h>
 
 #include <crawl_private.h>
 #include <crawl.h>
+#include <webbase_create.h>
 #include <robots.h>
 #include <sqlutil.h>
 #include <ftp.h>
@@ -117,8 +120,8 @@ static struct option long_options[] =
   {"hook", 1, 0, 0},
   /*- <bytes> Size in bytes of the longest url (default 255) */
   {"url_max_size", 1, 0, 0},
-  /*- <bytes> Maximum size in bytes of url buffer (default 100K) */
-  {"size_limit", 1, 0, 0},
+  /*- <bytes> Maximum size in bytes of hrefs stored per url (default 100K) */
+  {"size_hrefs", 1, 0, 0},
   /*- <bytes> Minimun size of a document (default none) */
   {"min", 1, 0, 0},
   /*- <number> Maximum number of pages retrieved from starting point (default 2) */
@@ -137,8 +140,6 @@ static struct option long_options[] =
   {"timeout_delay", 1, 0, 0},
   /*- <sec> Number of seconds to wait between two loads on the same server (default 60) */
   {"robot_delay", 1, 0, 0},
-  /*- <user:password> Auth part for all urls to load */
-  {"auth", 1, 0, 0},
   /*- <mime[,mime..]> Accepted mime types */
   {"accept", 1, 0, 0},
   /*- <re> Regular expression that every loaded pages must match */
@@ -147,8 +148,6 @@ static struct option long_options[] =
   {"noheuristics", 0, 0, 0},
   /*- Do not escape URLs sent to servers */
   {"unescape", 0, 0, 0},
-  /*- Do not comply with robot exclusion protocol */
-  {"norobot_exclusion", 0, 0, 0},
   /*- Mark each URL indexed with tag */
   {"tags", 1, 0, 0},
   /*- <string[ string...]> Add strings as robots.txt Allow clauses. */
@@ -159,10 +158,8 @@ static struct option long_options[] =
   {"regex_allow", 1, 0, 0},
   /*- <string[ string...]> Add strings as robots.txt Regex Disallow clauses. */
   {"regex_disallow", 1, 0, 0},
-  /*- <agent> Agent HTTP field content (default webbase/5.11) */
+  /*- <agent> Agent HTTP field content (default webbase/5.13) */
   {"agent", 1, 0, 0},
-  /*- Wait for every URLs from a server to be loaded before going to the next */
-  {"sleepy", 0, 0, 0},
   /*- Do not give up on server even if it timesout */
   {"sticky", 0, 0, 0},
   /*- Disable update heuristics */
@@ -171,7 +168,7 @@ static struct option long_options[] =
   {"update_rebuild", 0, 0, 0},
   /*- <number> Only get <number> url at a time from the base (default 200) */
   {"candidate_limit", 1, 0, 0},
-  /*- <path> directory where the URLs copies are stored (default /var/lib/webbase) */
+  /*- <path> directory where the URLs copies are stored (default /var/cache/webbase) */
   {"file_cache", 1, 0, 0},
   {0, 0, 0, CRAWL_OPTIONS}
 };
@@ -185,7 +182,7 @@ static struct option_help long_options_help[] =
   {"no_hook", "do not call inverted index hooks"},
   {"hook <name>", "use <name> inverted index library (default mifluz)"},
   {"url_max_size <bytes>", "size in bytes of the longest url (default 255)"},
-  {"size_limit <bytes>", "maximum size in bytes of url buffer (default 100K)"},
+  {"size_hrefs <bytes>", "maximum size in bytes of url buffer (default 100K)"},
   {"min <bytes>", "minimun size of a document (default none)"},
   {"depth <number>", "maximum number of pages retrieved from starting point (default 2)"},
   {"level <number>", "maximum number of hops from the starting point (default none)"},
@@ -195,20 +192,18 @@ static struct option_help long_options_help[] =
   {"not_found_delay <days>", "number of days to wait for loading again a page not found since the last time it was checked (default 30)"},
   {"timeout_delay <days>", "number of days to wait for loading again a page that timeouted the last time it was checked (default 30)"},
   {"robot_delay <sec>", "number of seconds to wait between two loads on the same server (default 60)"},
-  {"auth <user:password>", "auth part for all urls to load"},
   {"accept <mime types>", "accepted mime types"},
   {"filter <regexp>", "regular expression that every loaded pages must match"},
   {"noheuristics", "disable all loading heuristics"},
   {"unescape", "do not escape URLs sent to servers"},
-  {"norobot_exclusion", "do not comply with robot exclusion protocol"}, 
   {"tags", "mark each URL indexed with tag"},
   {"allow <list>", "allow a list of prefixes"},
   {"disallow <list>", "disallow a list of prefixes"},
   {"regex_allow <list>", "allow a list of regexs"},
   {"regex_disallow <list>", "disallow a list of regexs"},
-  {"agent <agent>", "Agent HTTP field content (default webbase/5.12)"},
+  {"agent <agent>", "User-Agent HTTP field content (default webbase/5.13)"},
   {"sleepy", "wait for every URLs from a server to be loaded before going to the next"},
-  {"sticky", "do not give up on server even if it timesout"},
+  {"sticky", "do not give up on server even if it timeouts"},
   {"update", "disable update heuristics"},
   {"update_rebuild", "rebuild the graph for the server, even if update is not needed"},
   {"candidate_limit <number>", "only get <number> url at a time from the base (default 200)"},
@@ -260,6 +255,7 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
 {
   crawl_params_t* params = params_alloc();
   webbase_url_start_t* start = &params->start_in_core;
+  params->agent = strdup(CRAWL_USER_AGENT);
 
   webbase_start_reset(start);
   dirsel_init();
@@ -291,8 +287,8 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
 	} else if(!strcmp(options[option_index].name, "url_max_size")) {
 	  start->url_max_size = atoi(optarg);
 	  break;
-	} else if(!strcmp(options[option_index].name, "size_limit")) {
-	  start->size_limit = atoi(optarg);
+	} else if(!strcmp(options[option_index].name, "size_hrefs")) {
+	  start->size_hrefs = atoi(optarg);
 	  break;
 	} else if(!strcmp(options[option_index].name, "min")) {
 	  start->min = atoi(optarg);
@@ -345,7 +341,6 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
 	  strcpy(start->field, optarg); \
           start->info |= flag; \
 	  break; 
-        S(auth,auth_length,WEBBASE_URL_START_AUTH);
         S(accept,accept_length,WEBBASE_URL_START_ACCEPT);
         S(filter,filter_length,WEBBASE_URL_START_FILTER);
         S(allow,allow_length,WEBBASE_URL_START_ALLOW);
@@ -355,6 +350,9 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[])
 #undef S
 	} else if(!strcmp(options[option_index].name, "no_hook")) {
 	  params->no_hook = 1;
+	} else if(!strcmp(options[option_index].name, "hook")) {
+	  free(params->agent);
+	  params->agent = strdup(optarg);
 	} else if(!strcmp(options[option_index].name, "hook")) {
 	  /*
 	   * Load the inverted index library 
@@ -809,6 +807,10 @@ void hp_unload(crawl_params_t* params, char* url, int keep_start)
   context.base = params->base;
   context.start = &start;
 
+  if(verbose) {
+    fprintf(stderr, "unload %s\n", url);
+  }
+
   /*
    * Set level to -1 for all start2url entries
    */
@@ -836,6 +838,57 @@ void hp_unload(crawl_params_t* params, char* url, int keep_start)
 #endif /* WEBBASE_LOCK */
 }
 
+static void hp_show_1(char* action_argp, MYSQL_RES* res , MYSQL_ROW row)
+{
+  MYSQL_FIELD* field;
+  unsigned int i;
+
+  for(i = 0; i < mysql_num_fields(res); i++) {
+    mysql_field_seek(res, i);
+    field = mysql_fetch_field(res);
+    printf("%s\t", row[i] ? row[i] : "NULL");
+  }
+  printf("\n");
+}
+
+void hp_show(crawl_params_t* params, char* url, char* fields, char* where)
+{
+  int url_length = strlen(url);
+  unsigned char url_md5[MD5_ASCII_SIZE];
+  char* query;
+  char* templ;
+
+  if(url_length > WEBBASE_URL_LENGTH) {
+    fprintf(stderr, "hp_show: %s too long (ignored)\n", url);
+    return;
+  }
+
+  str2md5ascii(url, url_length, url_md5);
+
+  if(fields == 0 || strlen(fields) == 0) {
+    fields = "start.*,url.*,url_complete.*";
+  }
+
+  if(where == 0) {
+    where = strdup("");
+  } else {
+    char* templ = " and ( %s ) ";
+    char* tmp_where = smalloc(strlen(templ) + strlen(where) + 1);
+    sprintf(tmp_where, templ, where);
+    where = tmp_where;
+  }
+  
+  templ = "select %s from start left join start2url on start.rowid = start2url.start left join url on start2url.url = url.rowid left join url_complete on url.complete_rowid = url_complete.rowid where start.url_md5 = '%.*s' %s";
+  query = smalloc(strlen(templ) + strlen(fields) + strlen(where) + MD5_ASCII_SIZE + 1);
+  
+  sprintf(query, templ, fields, MD5_ASCII_SIZE, url_md5, where);
+
+  sql_select(&params->base->mysql, 0, query, hp_show_1, 0);
+  
+  free(query);
+  free(where);
+}
+
 /*
  * Explore or update all the starting points
  */
@@ -883,7 +936,10 @@ static void noheuristics_1(char* contextp, MYSQL_RES* , MYSQL_ROW row)
   int rowid = atoi(row[0]);
   char query[256];
   
-  sprintf(query, "update url set crawl = from_unixtime(0) where rowid = %d", rowid);
+  //
+  // Do not set time to 0 to prevent ill side effects of timezone.
+  //
+  sprintf(query, "update url set crawl = from_unixtime(100000) where rowid = %d", rowid);
   smysql_query(&context->base->mysql, query);
 }
 
@@ -895,7 +951,7 @@ static void noheuristics(crawl_context_t* context)
   char query[256];
 
   if(context->params->noheuristics == 0) {
-    if(verbose > 2) fprintf(stderr, "\tnoheuristics: active\n");
+    if(verbose > 2) fprintf(stderr, "\theuristics: active\n");
     return;
   }
 
@@ -1020,11 +1076,46 @@ static void mirror_cleanup(crawl_context_t* context)
   webbase_t* base = context->base;
   webbase_url_start_t* start = context->start;
 
+  char tmp_table_name[64];
+
+  /*
+   * Move all records from start2url that belong to starting point
+   * to the s2u_tmp table.
+   */
+  {
+    const char* schema = webbase_table_schema(WEBBASE_SCHEMA_START2URL);
+    static char* from[] = {
+      "table start2url",
+      0
+    };
+    char table_subs[64];
+    static char* to[] = {
+      table_subs,
+      0
+    };
+    int schema_tmp_length = 0;
+    char* schema_tmp;
+
+    sprintf(tmp_table_name, "s2u_tmp%d", getpid());
+    sprintf(table_subs, "table %s", tmp_table_name);
+
+    schema_tmp = strsubs(schema, strlen(schema), &schema_tmp_length, from, to);
+    sprintf(query, "drop table if exists %s", tmp_table_name);
+    smysql_query(&base->mysql, query);
+    smysql_query(&base->mysql, schema_tmp);
+
+    sprintf(query, "insert into %s select * from start2url where start = %d and level < 0", tmp_table_name, start->rowid);
+    smysql_query(&base->mysql, query);
+
+    sprintf(query, "delete from start2url where start = %d and level < 0", start->rowid);
+    smysql_query(&base->mysql, query);
+  }
+
   /*
    * For all URLs that are out of scope for this start point but still
    * referenced by another start point, just kill the start2url entry.
    */
-  sprintf(query, "select a.url from start2url a,start2url b where a.start = %d and a.url = b.url and b.start != %d and a.level < 0", start->rowid, start->rowid);
+  sprintf(query, "select distinct a.url from %s a,start2url b where a.url = b.url", tmp_table_name);
   if(verbose > 2) fprintf(stderr, "\tmirror_cleanup: %s ...", query);
   smysql_query(&base->mysql, query);
   res = smysql_store_result(&base->mysql);
@@ -1033,7 +1124,7 @@ static void mirror_cleanup(crawl_context_t* context)
     while((row = mysql_fetch_row(res))) {
       int rowid = atoi(row[0]);
 
-      sprintf(query, "delete from start2url where start = %d and url = %d", start->rowid, rowid);
+      sprintf(query, "delete from %s where start = %d and url = %d", tmp_table_name, start->rowid, rowid);
       smysql_query(&base->mysql, query);
       unref_count++;
     }
@@ -1044,7 +1135,7 @@ static void mirror_cleanup(crawl_context_t* context)
    * For all URLs that are out of scope and uniquely referenced by this
    * starting point, delete all data.
    */
-  sprintf(query, "select url.rowid,url.complete_rowid,url.hookid,url.url from start2url,url where start2url.start = %d and start2url.url = url.rowid and start2url.level < 0", start->rowid);
+  sprintf(query, "select url.rowid,url.complete_rowid,url.hookid,url.url from %s a,url where a.url = url.rowid", tmp_table_name);
   if(verbose > 2) fprintf(stderr, "\tmirror_cleanup: %s ...", query);
   smysql_query(&base->mysql, query);
   res = smysql_store_result(&base->mysql);
@@ -1068,7 +1159,7 @@ static void mirror_cleanup(crawl_context_t* context)
     }
   }
   mysql_free_result(res);
-  sprintf(query, "delete from start2url where start = %d and level < 0", start->rowid);
+  sprintf(query, "drop table %s", tmp_table_name);
   smysql_query(&base->mysql, query);
 
   if(verbose > 1) fprintf(stderr, "\tmirror_cleanup: %d deletions, %d unref\n", deleted_count, unref_count);
@@ -1606,7 +1697,7 @@ static webbase_url_t* mirror_2(crawl_context_t* context, char* url)
   /*
    * It's not time to crawl yet
    */
-  if(!context->params->noheuristics && (webbase_url->w_crawl > time(0))) {
+  if(webbase_url->w_crawl > time(0)) {
     if(verbose > 1) fprintf(stderr, "\tnot time to crawl %s yet\n", url);
     return mirror_location(context, webbase_url);
   }
@@ -2014,7 +2105,7 @@ static int mirror_http(crawl_context_t* context, webbase_url_t* webbase_url, uri
 	if((error = webtools_reader(http, sd)) == WEBTOOLS_READER_OK ||
 	   error == WEBTOOLS_READER_TRUNC) {
 	  if(verbose > 1) fprintf(stderr, "\tloading %s : body read\n", url);
-	  webbase_url_hrefs_set(webbase_url, webbase_url->path, context->start->size_limit);
+	  webbase_url_hrefs_set(webbase_url, webbase_url->path, context->start->size_hrefs);
 
 #ifdef LANGREC
 	  {
@@ -2027,9 +2118,13 @@ static int mirror_http(crawl_context_t* context, webbase_url_t* webbase_url, uri
 	    html_content_t walk;
 
 	    // create a temporary file to store the text of the url being parsed
-	    char f_lang[64];
-	    sprintf(f_lang,"/tmp/file.langrec");
-	    write_file(f_lang,"",0);
+	    char* f_lang = smalloc(strlen(raw_path) + 64);
+	    sprintf(f_lang, "%s.langrec", raw_path);
+	    if(mknod(f_lang, 0777, S_IFREG) < 0) {
+	      fprintf(stderr, "creat(%s) failed:", f_lang);
+	      perror("");
+	      exit(1);
+	    }
 
 	    // fill the html_content_t structure
 	    html_content_reset(&walk);
@@ -2060,9 +2155,8 @@ static int mirror_http(crawl_context_t* context, webbase_url_t* webbase_url, uri
 	      strncpy(webbase_url->w_language, "unknown", WEBBASE_LANGUAGE_LENGTH);
 	    webbase_url->w_language[WEBBASE_LANGUAGE_LENGTH] = '\0';
 	    // erase temporary file
-	    char cmd[64];
-	    sprintf(cmd,"rm -f %s",f_lang);
-	    system(cmd);
+	    rm(f_lang);
+	    free(f_lang);
 	    }
   	  }
 #endif /* LANGREC */
@@ -2199,7 +2293,7 @@ static char* mirror_request_http(crawl_context_t* context, webbase_url_t* webbas
   /*
    * Fill If-Modified-Since field if appropriate.
    */
-  if(!context->params->noheuristics && !context->touch && (webbase_url->w_mtime > 0)) {
+  if(!context->touch && (webbase_url->w_mtime > 0)) {
     sprintf(modified_since, "If-Modified-Since: %s\r\n", time2str(webbase_url->w_mtime));
     if(verbose > 1) fprintf(stderr, "\tmirror_request_http: %.*s\n", (int)(strlen(modified_since) - 2), modified_since);
   }
@@ -2240,9 +2334,10 @@ static char* mirror_request_http(crawl_context_t* context, webbase_url_t* webbas
     }
   }
 
-  sprintf(request, "GET %s HTTP/1.0\r\nHost: %s\r\nUser-Agent: "CRAWL_USER_AGENT"\r\n%s%s%s\r\n",
+  sprintf(request, "GET %s HTTP/1.0\r\nHost: %s\r\nUser-Agent: %s\r\n%s%s%s\r\n",
 	  path,
 	  uri_netloc(url_object),
+	  context->params->agent,
 	  modified_since,
 	  (cookie ? cookie : ""),
 	  (auth ? auth : ""));
