@@ -47,6 +47,7 @@ typedef struct crawl_params {
   int candidate_limit;
   int sticky;
   WebbaseHook* hook;
+  char* agent;
 } crawl_params_t;
 
 struct option* crawl_options(struct option options[]);
@@ -59,6 +60,7 @@ crawl_params_t* crawl_alloc(int argc, char** argv, struct option options[]);
 void crawl_free(crawl_params_t* params);
 void hp_load(crawl_params_t* params);
 void hp_unload(crawl_params_t* params, char* url, int keep_start);
+void hp_show(crawl_params_t* params, char* url, char* fields, char* where);
 void hp_load_in_core(crawl_params_t* params, char* url);
 void hp_load_1(crawl_params_t* params, char* where);
 typedef void (*hp_action_callback)(crawl_params_t* params, webbase_url_start_t* start, webbase_url_t* webbase_url);
