@@ -404,7 +404,7 @@ static char* dirsel_comparable(char* netpath, uri_t* url_object)
   if(strncmp(fake_netpath, netpath, netpath_length))
     return 0;
 
-  return url_object->path;
+  return uri_all_path(url_object);
 }
 
 /*
