@@ -89,6 +89,9 @@ int http_header(char* arg, int, char* buffer, int buffer_size, int flag)
       char* tmp;
       if((tmp = strchr(lines[0], ' '))) {
 	int code = atoi(tmp);
+	/*
+	 * set url code (not found, not modified, ...)
+	 */
 	webbase_url_code_set(webbase_url, code);
       } else {
 	fprintf(stderr, "http_header: could not find code in %s, assume ok\n", lines[0]);
@@ -141,8 +144,18 @@ int http_body(char* arg, int, char* body, int body_size, int flag)
   static int parse_buffer_accumulate = 0;
 
   if(flag == WEBTOOLS_READER_START) {
+    /*
+     * get file name for storage
+     */
+#if 0
     webbase_url->path = uri_furi_string(webbase_url->w_url, strlen(webbase_url->w_url), URI_FURI_REAL_PATH);
+#else
+    webbase_url->path = webbase_url_file(webbase_url);
+#endif
     if(webbase_url->path) {
+      /*
+       * create file and intermediate directories
+       */
       creatp(webbase_url->path);
       write_file(webbase_url->path, body, body_size);
       webbase_url->w_info |= WEBBASE_URL_INFO_CONTENT;
@@ -151,6 +164,9 @@ int http_body(char* arg, int, char* body, int body_size, int flag)
     }
   } else if(webbase_url->path && body_size > 0 &&
 	    (flag == WEBTOOLS_READER_CONTINUE || flag == WEBTOOLS_READER_END)) {
+    /* 
+     * "read-in-progress", just append body to file
+     */
     append_file(webbase_url->path, body, body_size);
   }
 
