@@ -93,7 +93,7 @@ static int mime_accept_1(webbase_t* base, char* spec, char* content_type, char*
   static int ext_list_size = 0;
   
   int spec_length = strlen(spec);
-  int unallocated = spec_current_size;
+  int unallocated = spec_current_size == 0;
 
   static_alloc(&spec_current, &spec_current_size, spec_length + 1);
   if(unallocated)
@@ -142,6 +142,8 @@ static int mime_accept_1(webbase_t* base, char* spec, char* content_type, char*
     strcpy(ext_list, ext_tmp);
 
     mysql_free_result(res);
+
+    strcpy(spec_current, spec);
   }
 
   {
