@@ -62,7 +62,6 @@ static struct option long_options[] =
   {"host", 1, 0, 0},
   {"socket", 1, 0, 0},
   {"datadir", 1, 0, 0},
-  {"net_buffer", 1, 0, 0},
   {0, 0, 0, WEBBASE_OPTIONS}
 };
 
@@ -77,7 +76,6 @@ static struct option_help long_options_help[] =
   {"host <hostname>", "hostname of the MySQL database."},
   {"socket <file>", "Unix socket file full path name for local database connection."},
   {"datadir", "absolute path name of the directory containing the database."},
-  {"net_buffer <size>", "size of the network buffer for communications with the database (default is 1Mb)."},
   {"0", ""}
 };
 
@@ -97,11 +95,6 @@ webbase_t* webbase_alloc(int argc, char** argv, struct option options[])
   char* user = strdup("");
   char* password = strdup("");
 
-  /*
-   * Allow big transactions by default.
-   */
-  net_buffer_length = 1 * 1024 * 1024;
-
   opterr = 0;
   optind = 0;
   while(1) {
@@ -154,9 +147,6 @@ webbase_t* webbase_alloc(int argc, char** argv, struct option options[])
 	} else if(!strcmp(options[option_index].name, "port")) {
 	  base->mysql_port = atoi(optarg);
 	  break;
-	} else if(!strcmp(options[option_index].name, "net_buffer")) {
-	  net_buffer_length = atoi(optarg);
-	  break;
 	}
 	found = 0;
 	break;
@@ -198,10 +188,10 @@ webbase_t* webbase_alloc(int argc, char** argv, struct option options[])
     {
       char* home = getenv("HOME");
       if(home) {
-	//char* cnf_file = (char*)smalloc(strlen(home) + 32);
-	//sprintf(cnf_file, "%s/.my.cnf", home);
-	//mysql_options(&base->mysql, MYSQL_READ_DEFAULT_FILE, cnf_file);
-	//free(cnf_file);
+	char* cnf_file = (char*)smalloc(strlen(home) + 32);
+	sprintf(cnf_file, "%s/.my.cnf", home);
+	mysql_options(&base->mysql, MYSQL_READ_DEFAULT_FILE, cnf_file);
+	free(cnf_file);
       }
     }
     
@@ -408,7 +398,7 @@ void webbase_unlock(webbase_t* base, int varint, char* varchar)
 void webbase_default_start(webbase_t*, webbase_url_start_t* start)
 {
   start->url_max_size = WEBBASE_URL_START_DEFAULT_URL_MAX_SIZE;
-  start->size_limit = WEBBASE_URL_START_DEFAULT_SIZE_LIMIT;
+  start->size_hrefs = WEBBASE_URL_START_DEFAULT_SIZE_HREFS;
   start->min = WEBBASE_URL_START_DEFAULT_MIN;
   start->depth = WEBBASE_URL_START_DEFAULT_DEPTH;
   start->level = WEBBASE_URL_START_DEFAULT_LEVEL;
@@ -564,8 +554,6 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
 {
   static char* query = 0;
   static int query_size = 0;
-  static char* auth = 0;
-  static int auth_size = 0;
   static char* accept = 0;
   static int accept_size = 0;
   static char* filter = 0;
@@ -584,7 +572,6 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
   static int url_size = 0;
   static char* url_md5 = 0;
   static int url_md5_size = 0;
-  int has_auth = start->info & WEBBASE_URL_START_AUTH;
   int has_accept = start->info & WEBBASE_URL_START_ACCEPT;
   int has_filter = start->info & WEBBASE_URL_START_FILTER;
   int has_allow = start->info & WEBBASE_URL_START_ALLOW;
@@ -598,8 +585,6 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
 #define MINIMUM_QUERY_SIZE (20 * 1024)  
   static_alloc(&query, &query_size, MINIMUM_QUERY_SIZE);
 
-  if(has_auth)
-    sql_quote_char(&auth, &auth_size, start->auth, strlen(start->auth));
   if(has_accept)
     sql_quote_char(&accept, &accept_size, start->accept, strlen(start->accept));
   if(has_filter)
@@ -617,7 +602,6 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
 
   static_alloc(&query, &query_size, MINIMUM_QUERY_SIZE +
 	       url_size +
-	       auth_size +
 	       accept_size +
 	       filter_size +
 	       allow_size +
@@ -635,7 +619,7 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
     strcat(query, ", " #field " = "); \
     strcat(query, start->field == default_start->field ? "null" : sql_itoa(start->field))
     S(url_max_size);
-    S(size_limit);
+    S(size_hrefs);
     S(min);
     S(depth);
     S(level);
@@ -647,9 +631,8 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
     S(robot_delay);
     S(delay);
 #undef S
-    sprintf(query + strlen(query), ", auth = %c%s%c, accept = %c%s%c, filter = %c%s%c, allow = %c%s%c, disallow = %c%s%c, regex_allow = %c%s%c, regex_disallow = %c%s%c, hook_info = %c%s%c, count = %d",
+    sprintf(query + strlen(query), ", accept = %c%s%c, filter = %c%s%c, allow = %c%s%c, disallow = %c%s%c, regex_allow = %c%s%c, regex_disallow = %c%s%c, hook_info = %c%s%c, count = %d",
 #define S(f,hasf) (hasf ? '\'' : ' '), (hasf ? f : "null"), (hasf ? '\'' : ' ')
-	  S(auth,has_auth),
 	  S(accept,has_accept),
 	  S(filter,has_filter),
 	  S(allow,has_allow),
@@ -672,7 +655,7 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
     strcat(query, start->field == default_start->field ? "null" : sql_itoa(start->field)); \
     strcat(query, ", ")
     S(url_max_size);
-    S(size_limit);
+    S(size_hrefs);
     S(min);
     S(depth);
     S(level);
@@ -684,9 +667,8 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
     S(robot_delay);
     S(delay);
 #undef S
-    sprintf(query + strlen(query), "%c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %d",
+    sprintf(query + strlen(query), "%c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %c%s%c, %d",
 #define S(f,hasf) (hasf ? '\'' : ' '), (hasf ? f : "null"), (hasf ? '\'' : ' ')
-	  S(auth,has_auth),
 	  S(accept,has_accept),
 	  S(filter,has_filter),
 	  S(allow,has_allow),
@@ -711,7 +693,7 @@ void webbase_update_start(webbase_t* base, webbase_url_start_t* start)
 void webbase_merge_start(webbase_url_start_t* to, webbase_url_start_t* from)
 {
   if(from->url_max_size >= 0) to->url_max_size = from->url_max_size;
-  if(from->size_limit >= 0) to->size_limit = from->size_limit;
+  if(from->size_hrefs >= 0) to->size_hrefs = from->size_hrefs;
   if(from->min >= 0) to->min = from->min;
   if(from->depth > 0) to->depth = from->depth;
   if(from->level > 0) to->level = from->level;
@@ -728,7 +710,6 @@ void webbase_merge_start(webbase_url_start_t* to, webbase_url_start_t* from)
     strcpy(to->field, from->field); \
     to->info |= flag; \
   }
-  S(auth,auth_length,WEBBASE_URL_START_AUTH);
   S(accept,accept_length,WEBBASE_URL_START_ACCEPT);
   S(filter,filter_length,WEBBASE_URL_START_FILTER);
   S(allow,allow_length,WEBBASE_URL_START_ALLOW);
@@ -741,7 +722,6 @@ void webbase_merge_start(webbase_url_start_t* to, webbase_url_start_t* from)
 
 void webbase_start_free(webbase_url_start_t* start)
 {
-  if(start->auth) free(start->auth);
   if(start->accept) free(start->accept);
   if(start->filter) free(start->filter);
   if(start->allow) free(start->allow);
@@ -761,7 +741,7 @@ void webbase_start_reset(webbase_url_start_t* start)
   memset(start->url_md5, '\0', sizeof(start->url_md5));
   start->info = 0;
   start->url_max_size = -1;
-  start->size_limit = -1;
+  start->size_hrefs = -1;
   start->min = -1;
   start->depth = -1;
   start->level = -1;
@@ -771,7 +751,6 @@ void webbase_start_reset(webbase_url_start_t* start)
   start->not_found_delay = '\377';
   start->timeout_delay = '\377';
   start->robot_delay = '\377';
-  if(start->auth) start->auth[0] = '\0';
   if(start->accept) start->accept[0] = '\0';
   if(start->filter) start->filter[0] = '\0';
   if(start->allow) start->allow[0] = '\0';
@@ -818,7 +797,7 @@ static webbase_url_start_t* webbase_decode_start(webbase_t* base, MYSQL_RES *res
       int value = row[i] ? atoi(row[i]) : -1; \
       start->f = value >= 0 ? value : default_start->f; 
     S(url_max_size);
-    S(size_limit);
+    S(size_hrefs);
     S(min);
     S(depth);
     S(level);
@@ -838,7 +817,6 @@ static webbase_url_start_t* webbase_decode_start(webbase_t* base, MYSQL_RES *res
 	strcpy(start->f, row[i]); \
         start->info |= flag; \
       }
-    S(auth, auth_length, WEBBASE_URL_START_AUTH);
     S(accept, accept_length, WEBBASE_URL_START_ACCEPT);
     S(filter, filter_length, WEBBASE_URL_START_FILTER);
     S(allow, allow_length, WEBBASE_URL_START_ALLOW);
