@@ -83,8 +83,8 @@ void webbase_lock_ignore(webbase_t* base, int varint, char* varchar);
 /* 
  * start
  */
-#define WEBBASE_START_FIELDS "rowid,url,url_md5,info+0,url_max_size,size_limit,min,depth,level,timeout,loaded_delay,modified_delay,not_found_delay,timeout_delay,robot_delay,auth,accept,filter,allow,disallow,regex_allow,regex_disallow,hook_info,count,delay"
-#define WEBBASE_START_FIELDS_INSERT "rowid,url,url_md5,info,url_max_size,size_limit,min,depth,level,timeout,loaded_delay,modified_delay,not_found_delay,timeout_delay,robot_delay,delay,auth,accept,filter,allow,disallow,regex_allow,regex_disallow,hook_info,count"
+#define WEBBASE_START_FIELDS "rowid,url,url_md5,info+0,url_max_size,size_hrefs,min,depth,level,timeout,loaded_delay,modified_delay,not_found_delay,timeout_delay,robot_delay,accept,filter,allow,disallow,regex_allow,regex_disallow,hook_info,count,delay"
+#define WEBBASE_START_FIELDS_INSERT "rowid,url,url_md5,info,url_max_size,size_hrefs,min,depth,level,timeout,loaded_delay,modified_delay,not_found_delay,timeout_delay,robot_delay,delay,accept,filter,allow,disallow,regex_allow,regex_disallow,hook_info,count"
 
 /*
  * Callback prototype when walking the start table
