@@ -39,11 +39,11 @@ create table start ( \n\
   url text not null, \n\
   url_key char(80) not null default '', \n\
   url_md5 char(32) binary not null default '', \n\
-  info set ('sleepy', 'unescape', 'auth', 'nocookie', 'accept', 'heuristics', \n\
+  info set ('sleepy', 'unescape', 'nocookie', 'accept', 'heuristics', \n\
             'sticky', 'filter', 'homefree', 'virgin', 'exploring', 'explored', \n\
             'updating', 'in_core', 'allow', 'disallow', 'hook_info'), \n\
   url_max_size smallint default -1, \n\
-  size_limit int default 100000, \n\
+  size_hrefs int default 102400, \n\
   min int default -1, \n\
   depth int default 2, \n\
   level int default 1000000, \n\
@@ -53,7 +53,6 @@ create table start ( \n\
   not_found_delay smallint default -1, \n\
   timeout_delay smallint default -1, \n\
   robot_delay smallint default -1, \n\
-  auth varchar(255) binary, \n\
   accept varchar(255) binary, \n\
   filter varchar(255) binary, \n\
   allow varchar(255) binary, \n\
@@ -653,3 +652,13 @@ void webbase_schema()
   for(i = 0; i < sizeof(default_schema) / sizeof(char*); i++)
     printf("%s", default_schema[i]);
 }
+
+const char* webbase_table_schema(int table)
+{
+  if(table < 0 || table >= WEBBASE_SCHEMA_LENGTH) {
+    fprintf(stderr, "webbase_table_schema: invalid table number %d (must be >= 0 and < %d\n", table, WEBBASE_SCHEMA_LENGTH);
+    return 0;
+  }
+
+  return default_schema[table];
+}
