@@ -21,7 +21,22 @@
 
 #include <mysql.h>
 
+#define WEBBASE_SCHEMA_START		0
+#define WEBBASE_SCHEMA_ROBOTS		1
+#define WEBBASE_SCHEMA_COOKIES		2
+#define WEBBASE_SCHEMA_START2URL	3
+#define WEBBASE_SCHEMA_URL		4
+#define WEBBASE_SCHEMA_URL_COMPLETE	5
+#define WEBBASE_SCHEMA_MIME_RESTRICT	6
+#define WEBBASE_SCHEMA_MIME2EXT		7
+#define WEBBASE_SCHEMA_HOME_RE		8
+#define WEBBASE_SCHEMA_STATISTICS	9
+#define WEBBASE_SCHEMA_LOCKS		10
+
+#define WEBBASE_SCHEMA_LENGTH		11
+
 void webbase_create(MYSQL* mysql, const char** schema, int schema_length);
 void webbase_schema();
+const char* webbase_table_schema(int table);
 
 #endif /* webbase_create_h */
