@@ -409,9 +409,9 @@ void webbase_url_mtime_fix(webbase_url_t* webbase_url)
   }
 }
 
-void webbase_url_hrefs_set(webbase_url_t* webbase_url, char* path, int size_limit)
+void webbase_url_hrefs_set(webbase_url_t* webbase_url, char* path, int size_hrefs)
 {
-  html_href(path, webbase_url, size_limit);
+  html_href(path, webbase_url, size_hrefs);
 }
 
 char* webbase_url_file(webbase_url_t* webbase_url)
