@@ -169,7 +169,7 @@ typedef struct webbase_url_common {
  * Default values
  */
 #define WEBBASE_URL_START_DEFAULT_URL_MAX_SIZE		254
-#define WEBBASE_URL_START_DEFAULT_SIZE_LIMIT      	100000
+#define WEBBASE_URL_START_DEFAULT_SIZE_HREFS      	(100 * 1024)
 #define WEBBASE_URL_START_DEFAULT_MIN      		0
 #define WEBBASE_URL_START_DEFAULT_DEPTH      		2
 #define WEBBASE_URL_START_DEFAULT_LEVEL      		100000
@@ -185,7 +185,6 @@ typedef struct webbase_url_common {
  */
 #define WEBBASE_URL_START_SLEEPY	 0x00001
 #define WEBBASE_URL_START_UNESCAPE	 0x00002
-#define WEBBASE_URL_START_AUTH		 0x00004
 #define WEBBASE_URL_START_NOCOOKIE	 0x00008
 #define WEBBASE_URL_START_ACCEPT	 0x00010
 #define WEBBASE_URL_START_HEURISTICS	 0x00020
@@ -227,7 +226,7 @@ typedef struct webbase_url_start {
   /* Maximum size of a URL */
   int url_max_size;
   /* Maximum cumulated size of hrefs in document */
-  int size_limit;
+  int size_hrefs;
   /* Minimum size of an indexable document */
   int min;
   /* Maximum number of URL to retrieve from this point */
@@ -246,9 +245,6 @@ typedef struct webbase_url_start {
   char timeout_delay;
   /* Reload delay for robots.txt files */
   char robot_delay;
-  /* User specified auth part for the URL */
-  char* auth;
-  int auth_length;
   /* List of accepted MIME types */
   char* accept;
   int accept_length;
@@ -407,7 +403,7 @@ void webbase_url_content_length_set(webbase_url_t* webbase_url, int content_leng
 /*
  * Parse hrefs from <path> HTML file and store in url_complete fields.
  */
-void webbase_url_hrefs_set(webbase_url_t* webbase_url, char* path, int size_limit);
+void webbase_url_hrefs_set(webbase_url_t* webbase_url, char* path, int size_hrefs);
 /*
  * Print human readable representation of <webbase_url> 
  */
