@@ -112,6 +112,8 @@ webtools_params_t* webtools_alloc(int argc, char** argv, struct option options[]
 {
   webtools_params_t* params = params_alloc();
 
+  params->size_limit = WEBTOOLS_SIZE_LIMIT;
+
   opterr = 0;
   optind = 0;
   while(1) {
@@ -444,7 +446,6 @@ static webtools_params_t* params_alloc()
   hash_set_allocator(params->options, 0, hnode_free, 0);
   params->host2ip = hash_create(HASHCOUNT_T_MAX, 0, 0);
   hash_set_allocator(params->host2ip, 0, hnode_free, 0);
-  params->size_limit = 100 * 1024;
 
   return params;
 }
