@@ -19,6 +19,14 @@
 #ifndef _creatp_h
 #define _creatp_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int creatp(char* filename);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* creatp_h */
