@@ -23,7 +23,7 @@
 extern "C" {
 #endif
 
-char* strsubs(char* string, int string_size, int* size, char** from_array, char** to_array);
+char* strsubs(const char* string, int string_size, int* size, char** from_array, char** to_array);
 
 #ifdef __cplusplus
 }
